@@ -211,7 +211,7 @@ class DBConnect:
                 'page_size': str, 'current': str, 'columns': str, 'sort_order': str,
                 'filtered_value': str, 'start_date': str, 'end_date': str, 'date_type': str
             },
-            optional={'start_date': '', 'end_date': '', 'date_type':'update_time'})
+            optional={'start_date': '', 'end_date': '', 'date_type': 'update_time'})
         param = parameter.param_url
         try:
             page_size = int(param['page_size'])  # 每页条数
@@ -263,9 +263,27 @@ class DBConnect:
             if start_date and end_date:
                 find_dict[param['date_type']] = {
                     '$gte': start_date, '$lte': end_date}
-            find_data = self.mongo_collection.find(find_dict)
+            # 对排序规则处理
+            if sort_list:
+                find_data = self.mongo_collection.find(find_dict).sort(sort_list).limit(
+                    page_size).skip(page_size * current)
+            else:
+                find_data = self.mongo_collection.find(find_dict).limit(
+                    page_size).skip(page_size * current)
+            # 处理返回数据
             records_filtered = find_data.count()
-            if not records_filtered:
+            # 判断数据是否为空
+            if find_data.count():
+                # 处理返回数据
+                query_result = handle_db_to_list(find_data)
+                return {
+                    'records_total': self.mongo_collection.estimated_document_count() - remove_count,
+                    'records_filtered': records_filtered,
+                    'query_result': query_result,
+                    'total_pages': math.ceil(records_filtered / page_size),
+                    'remove_count': remove_count,
+                }
+            else:
                 return {
                     'records_total': self.mongo_collection.estimated_document_count() - remove_count,
                     'records_filtered': 0,
@@ -273,20 +291,6 @@ class DBConnect:
                     'total_pages': 0,
                     'remove_count': remove_count,
                 }
-            if sort_list:
-                find_data.sort(sort_list).limit(
-                    page_size).skip(page_size * current)
-            else:
-                find_data.limit(page_size).skip(page_size * current)
-            # 处理返回数据
-            query_result = handle_db_to_list(find_data)
-            return {
-                'records_total': self.mongo_collection.estimated_document_count() - remove_count,
-                'records_filtered': records_filtered,
-                'query_result': query_result,
-                'total_pages': math.ceil(records_filtered / page_size),
-                'remove_count': remove_count,
-            }
         except Exception as err:
             handle_abnormal(
                 message='计算组件分页参数异常',
